==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/ovirt/v1/DiskBuilder.java <==
package io.fabric8.openshift.api.model.hive.ovirt.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DiskBuilder extends DiskFluentImpl<DiskBuilder> implements VisitableBuilder<Disk,DiskBuilder>{
  public DiskBuilder() {
    this(false);
  }
  public DiskBuilder(Boolean validationEnabled) {
    this(new Disk(), validationEnabled);
  }
  public DiskBuilder(DiskFluent<?> fluent) {
    this(fluent, false);
  }
  public DiskBuilder(DiskFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Disk(), validationEnabled);
  }
  public DiskBuilder(DiskFluent<?> fluent,Disk instance) {
    this(fluent, instance, false);
  }
  public DiskBuilder(DiskFluent<?> fluent,Disk instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withSizeGB(instance.getSizeGB());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public DiskBuilder(Disk instance) {
    this(instance,false);
  }
  public DiskBuilder(Disk instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withSizeGB(instance.getSizeGB());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  DiskFluent<?> fluent;
  Boolean validationEnabled;
  public Disk build() {
    Disk buildable = new Disk(fluent.getSizeGB());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/ovirt/v1/DiskBuilder.java <==
package io.fabric8.openshift.api.model.hive.ovirt.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DiskBuilder extends DiskFluent<DiskBuilder> implements VisitableBuilder<Disk,DiskBuilder>{
  public DiskBuilder() {
    this(false);
  }
  public DiskBuilder(Boolean validationEnabled) {
    this(new Disk(), validationEnabled);
  }
  public DiskBuilder(DiskFluent<?> fluent) {
    this(fluent, false);
  }
  public DiskBuilder(DiskFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Disk(), validationEnabled);
  }
  public DiskBuilder(DiskFluent<?> fluent,Disk instance) {
    this(fluent, instance, false);
  }
  public DiskBuilder(DiskFluent<?> fluent,Disk instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new Disk());

    if (instance != null) {
      fluent.withSizeGB(instance.getSizeGB());
      fluent.withSizeGB(instance.getSizeGB());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public DiskBuilder(Disk instance) {
    this(instance,false);
  }
  public DiskBuilder(Disk instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new Disk());

    if (instance != null) {
      this.withSizeGB(instance.getSizeGB());
      this.withSizeGB(instance.getSizeGB());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  DiskFluent<?> fluent;
  Boolean validationEnabled;
  public Disk build() {
    Disk buildable = new Disk(fluent.getSizeGB());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
